# ![chartwerk](docs/images/logo.png)

[![PyPI version](https://badge.fury.io/py/django-chartwerk.svg)](https://pypi.org/project/django-chartwerk/)
[![PyPI](https://img.shields.io/pypi/status/django-chartwerk.svg)](https://pypi.org/project/django-chartwerk/)
[![Requirements Status](https://img.shields.io/requires/github/DallasMorningNews/django-chartwerk.svg?maxAge=2592000)](https://requires.io/github/DallasMorningNews/django-chartwerk/requirements/?branch=master)


A Django application to manage, create and share Chartwerk charts, built with [Django REST framework](http://www.django-rest-framework.org/).

For the React/Redux-based chart editor, see [chartwerk-editor](https://github.com/DallasMorningNews/chartwerk-editor).

Documentation hosted at [django-chartwerk.readthedocs.org](https://django-chartwerk.readthedocs.io).
